@@ -51,6 +51,7 @@ class BaseReportListAPIView(LimitOffsetPaginationListAPIView):
     serializer_class = None
     model = None
     select_related_fields = ()  # must be tuple or list
+    with_platforms_sample = False
 
     def get_model(self):
         if not self.model:
@@ -70,6 +71,8 @@ class BaseReportListAPIView(LimitOffsetPaginationListAPIView):
                                                  date__range=[
                                                      self.date_from, self.date_to
                                                  ])
+        if self.with_platforms_sample:
+            return qs.filter(platform_id=self.platform_id)
         return qs
 
 
